@@ -229,7 +229,12 @@ NVProbeDDC (ScrnInfoPtr pScrn, int bus)
     xf86DrvMsg(pScrn->scrnIndex, X_INFO, 
                "Probing for EDID on I2C bus %s...\n", bus ? "B" : "A");
 
-    if ((MonInfo = xf86DoEDID_DDC2(pScrn->scrnIndex, pNv->I2C))) {
+#ifdef EDID_COMPLETE_RAWDATA
+    MonInfo = xf86DoEEDID(XF86_SCRN_ARG(pScrn), pNv->I2C, TRUE);
+#else
+    MonInfo = xf86DoEDID_DDC2(XF86_SCRN_ARG(pScrn), pNv->I2C);
+#endif
+    if (MonInfo) {
        xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
                   "DDC detected a %s:\n", MonInfo->features.input_type ?
                   "DFP" : "CRT");
@@ -282,7 +287,7 @@ static void nv10GetConfig (NVPtr pNv)
     }
 #endif
 
-#if XSERVER_LIBPCIACCESS
+#ifdef XSERVER_LIBPCIACCESS
     {
     /* [AGP]: I don't know if this is correct */
     struct pci_device *dev = pci_device_find_by_slot(0, 0, 0, 1);
@@ -341,7 +346,7 @@ NVCommonSetup(ScrnInfoPtr pScrn)
     int FlatPanel = -1;   /* really means the CRTC is slaved */
     Bool Television = FALSE;
     void *tmp;
-#if XSERVER_LIBPCIACCESS
+#ifdef XSERVER_LIBPCIACCESS
     int err;
 #endif
 
@@ -373,7 +378,7 @@ NVCommonSetup(ScrnInfoPtr pScrn)
     pVga->MMIOBase   = (CARD8 *)pNv;
     pVga->MMIOOffset = 0;
 
-#if XSERVER_LIBPCIACCESS
+#ifdef XSERVER_LIBPCIACCESS
     err = pci_device_map_range(pNv->PciInfo, pNv->IOAddress, 0x01000000,
 			       PCI_DEV_MAP_FLAG_WRITABLE, &tmp);
     if (err != 0) {
@@ -486,6 +491,8 @@ NVCommonSetup(ScrnInfoPtr pScrn)
 
     pNv->Television = FALSE;
 
+    vgaHWGetIOBase(pVga);
+
     if(!pNv->twoHeads) {
        pNv->CRTCnumber = 0;
        if((monitorA = NVProbeDDC(pScrn, 0))) {
@@ -663,11 +670,11 @@ NVCommonSetup(ScrnInfoPtr pScrn)
               (!monitorA->features.input_type && !pNv->FlatPanel))
            {
                if(monitorB) { 
-                  xfree(monitorB);
+                  free(monitorB);
                   monitorB = NULL;
                }
            } else {
-              xfree(monitorA);
+              free(monitorA);
               monitorA = NULL;
            }
        }
@@ -676,7 +683,7 @@ NVCommonSetup(ScrnInfoPtr pScrn)
            if((monitorB->features.input_type && !pNv->FlatPanel) ||
               (!monitorB->features.input_type && pNv->FlatPanel)) 
            {
-              xfree(monitorB);
+              free(monitorB);
            } else {
               monitorA = monitorB;
            }
